summaryrefslogtreecommitdiff
path: root/sw/source/core/doc/htmltbl.cxx
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2016-04-22 10:08:07 +0200
committerStephan Bergmann <sbergman@redhat.com>2016-04-22 10:08:07 +0200
commit85825e0fd54551735ef05b8484f71974734b9135 (patch)
tree8bece458e55c1b5eab7559076579bf76cca8df68 /sw/source/core/doc/htmltbl.cxx
parentfc233b52ce2acc1bcd7cecc3d51bcab870c81932 (diff)
Avoid reserved identifiers
Change-Id: I27ff0f4f0eb395d7e0a60dd604758c220a3134c4
Diffstat (limited to 'sw/source/core/doc/htmltbl.cxx')
-rw-r--r--sw/source/core/doc/htmltbl.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/sw/source/core/doc/htmltbl.cxx b/sw/source/core/doc/htmltbl.cxx
index 89e618e802a0..3fce21e7d42d 100644
--- a/sw/source/core/doc/htmltbl.cxx
+++ b/sw/source/core/doc/htmltbl.cxx
@@ -1100,7 +1100,7 @@ void SwHTMLTableLayout::AutoLayoutPass2( sal_uInt16 nAbsAvail, sal_uInt16 nRelAv
// Remember the available width for which the table was calculated.
// This is a good place as we pass by here for the initial calculation
// of the table in the parser and for each _Resize call.
m_nLastResizeAbsAvail = nAbsAvail;
// Step 1: The available space is readjusted for the left/right border,
@@ -1702,7 +1702,7 @@ void SwHTMLTableLayout::SetWidths( bool bCallPass2, sal_uInt16 nAbsAvail,
const SwTableLines& rLines = m_pSwTable->GetTabLines();
for (size_t n = 0; n < rLines.size(); ++n)
{
- _CheckBoxWidth( *rLines[ n ], nSize );
+ CheckBoxWidth( *rLines[ n ], nSize );
}
}
#endif
@@ -1723,7 +1723,7 @@ void SwHTMLTableLayout::SetWidths( bool bCallPass2, sal_uInt16 nAbsAvail,
}
}
-void SwHTMLTableLayout::_Resize( sal_uInt16 nAbsAvail, bool bRecalc )
+void SwHTMLTableLayout::Resize_( sal_uInt16 nAbsAvail, bool bRecalc )
{
// If bRecalc is set, the table's content changed.
// We need to execute pass 1 again.
@@ -1744,7 +1744,7 @@ void SwHTMLTableLayout::_Resize( sal_uInt16 nAbsAvail, bool bRecalc )
IMPL_LINK_NOARG_TYPED( SwHTMLTableLayout, DelayedResize_Impl, Timer*, void )
{
m_aResizeTimer.Stop();
- _Resize( m_nDelayedResizeAbsAvail, m_bDelayedResizeRecalc );
+ Resize_( m_nDelayedResizeAbsAvail, m_bDelayedResizeRecalc );
}
bool SwHTMLTableLayout::Resize( sal_uInt16 nAbsAvail, bool bRecalc,
@@ -1800,7 +1800,7 @@ bool SwHTMLTableLayout::Resize( sal_uInt16 nAbsAvail, bool bRecalc,
{
if( m_aResizeTimer.IsActive() )
m_aResizeTimer.Stop();
- _Resize( nAbsAvail, bRecalc );
+ Resize_( nAbsAvail, bRecalc );
}
else if( nDelay > 0 )
{
@@ -1811,7 +1811,7 @@ bool SwHTMLTableLayout::Resize( sal_uInt16 nAbsAvail, bool bRecalc,
}
else
{
- _Resize( nAbsAvail, bRecalc );
+ Resize_( nAbsAvail, bRecalc );
}
return true;
@@ -1100,7 +1100,7 @@ void SwHTMLTableLayout::AutoLayoutPass2( sal_uInt16 nAbsAvail, sal_uInt16 nRelAv
// Remember the available width for which the table was calculated.
// This is a good place as we pass by here for the initial calculation
- // of the table in the parser and for each _Resize call.
+ // of the table in the parser and for each Resize_ call.
m_nLastResizeAbsAvail = nAbsAvail;
// Step 1: The available space is readjusted for the left/right border,